import requests

baseUrl = "https://the-one-api.dev/v2/"

def connect(url):
    r = requests.get(url, headers={'Authorization': 'Bearer UFqJQJQzA0I28Tg9GfFs'})
    return r

def get_all_data(type, filter, limit): # Returns all data for certain parameter
    if filter and limit:
        url = baseUrl + type + "?" + filter + "=" + limit
        r = connect(url)
    else:
        r = connect(baseUrl + type)

    data_length = len(r.json()['docs'])
    
    out = []
    for i in range(data_length):
        out.append(r.json()['docs'][i]) 
    return out


import api, sys, json

def init():
    try:
        main(sys.argv[1], is_filter_param(sys.argv), is_filter_activated(sys.argv))
    except IndexError:
        print("Please refer to the Documentation for parameters.")
    except json.decoder.JSONDecodeError:
        print("There didn't seem to be a match. Double check spelling and try again.")

def main(type, filter=None, limit=None):
    print(api.get_all_data(type, filter, limit))

def is_filter_param(argv):
    if len(argv) > 2:
        filter = sys.argv[2]
        return filter

def is_filter_activated(argv):
    if len(argv) > 3:
        limit = sys.argv[3]
        return limit